AiException class

Raised when a provider cannot complete a request.

Implemented types

Constructors

AiException(String message)
Creates an AI transport or protocol error.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Message shown to the user.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited