mappingPaths property

List<String>? mappingPaths
final

Array of paths to multiple mapping files or debug symbols.

Specifies multiple mapping files (mapping.txt) or debug symbol archives (native-debug-symbols.zip) for uploading. Useful when dealing with multiple build variants or library mappings.

Implementation

final List<String>? mappingPaths;