obbMainReferencesVersion property

int? obbMainReferencesVersion
final

References version for the main expansion file.

Specifies the version code that the main expansion file (OBB) references. Used for large games or apps that require additional asset files beyond the base APK size limits.

Implementation

final int? obbMainReferencesVersion;