syncImageUpload property

bool syncImageUpload
final

Whether to use SHA256 comparison for intelligent image uploading.

When true, compares SHA256 hashes of local images and screenshots with those already in Google Play Store to skip uploading identical files, improving upload efficiency and speed. Default: false

Implementation

final bool syncImageUpload;