groups property
Comma-separated list of tester group aliases.
Group aliases that define collections of testers in Firebase Console.
Groups must be created and configured in Firebase App Distribution.
Mutually exclusive with groupsFile.
Example: "qa-team,beta-users,internal-staff"
Implementation
final String? groups;