repoName property

String repoName
getter/setter pair

GitHub repository name for release publishing.

The name of the target repository where releases will be created and assets uploaded. Must be accessible with the provided token. Repository must exist and token must have appropriate permissions.

Example: "my-flutter-app"

Implementation

late String repoName;