targetCommitish property
Git commit-ish the release tag is created from.
Defaults to the repository's default branch when omitted. Accepts a branch name or a full commit SHA.
Implementation
late String? targetCommitish;
Git commit-ish the release tag is created from.
Defaults to the repository's default branch when omitted. Accepts a branch name or a full commit SHA.
late String? targetCommitish;