Builder class

A command to build and optionally distribute the app.

The Builder class provides functionality to build Android and iOS apps, as well as custom platforms. It also supports optional distribution of the built apps using the Publisher class.

To use this class, invoke the build command with the desired flags:

distribute build --android --publish
Inheritance

Constructors

Builder()
Initializes the Builder class.

Properties

aliases List<String>
Alternate names for this command.
no setterinherited
androidBinary String
The Android binary type (APK or AAB).
no setter
argParser → ArgParser
Configures the argument parser for the build command.
no setteroverride
argResults → ArgResults?
The parsed argument results for this command.
no setterinherited
buildAndroid bool
Checks if the Android build flag is enabled.
no setter
buildIOS bool
Checks if the iOS build flag is enabled.
no setter
category String
The command's category.
no setterinherited
description String
Provides a description of the build command.
no setteroverride
environment Environment
The environment configuration for the build process.
getter/setter pair
globalResults → ArgResults?
The parsed global argument results.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
Whether or not this command should be hidden from help listings.
no setterinherited
invocation String
A single-line template for how to invoke this command (e.g. "pub get package").
no setterinherited
logger ColorizeLogger
Logger instance for logging messages.
latefinal
name String
The name of the build command.
no setteroverride
parent → Command?
The command's parent command, if this is a subcommand.
no setterinherited
publish bool
Checks if the publish flag is enabled.
no setter
publisher Publisher
The publisher instance for distributing the app.
latefinal
runner → CommandRunner?
The command runner for this command.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subcommands Map<String, Command>
An unmodifiable view of all sublevel commands of this command.
no setterinherited
suggestionAliases List<String>
Alternate non-functional names for this command.
no setterinherited
summary String
A short description of this command, included in parent's CommandRunner.usage.
no setterinherited
takesArguments bool
Whether or not this command takes positional arguments in addition to options.
no setterinherited
usage String
Generates a string displaying usage information for this command.
no setterinherited
usageFooter String?
An optional footer for usage.
no setterinherited

Methods

addSubcommand(Command command) → void
Adds Command as a subcommand of this.
inherited
build({List<String> androidArgs = const [], List<String> iosArgs = const [], Map<String, List<String>>? customBuildArgs}) Future<int>
Builds the app for the specified platforms and arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printUsage() → void
Prints the usage information for this command.
inherited
run() Future
Executes the build command to build and optionally distribute the app.
override
toString() String
A string representation of this object.
inherited
usageException(String message) → Never
Throws a UsageException with message.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited