CleanService class

Performs the destructive portion of cleanup behind strict path guards.

Constructors

CleanService(ColorizeLogger logger, {required bool dryRun, Directory? projectRoot, Iterable<String> protectedPaths = const []})

Properties

dryRun bool
final
hashCode int
The hash code for this object.
no setterinherited
logger ColorizeLogger
final
projectRoot Directory
final
protectedPaths Set<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

flutterClean() Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
outputs(Iterable<String> directories) Future<int>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited