androidPlaystoreTrackPromoteTo property
The Play Store track to promote the build to after distribution (e.g., production).
Implementation
String androidPlaystoreTrackPromoteTo = 'production';
The Play Store track to promote the build to after distribution (e.g., production).
String androidPlaystoreTrackPromoteTo = 'production';