HookResult class

Result of a pre/post command.

Constructors

HookResult({required String command, required int exitCode, required Duration duration, bool ignored = false, bool timedOut = false})
const

Properties

command → String
final
duration → Duration
final
exitCode → int
final
hashCode → int
The hash code for this object.
no setterinherited
ignored → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
succeeded → bool
no setter
timedOut → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited