isCapturing property
bool
get
isCapturing
Whether the current zone is collecting output instead of printing it.
Implementation
static bool get isCapturing => Zone.current[_zoneSink] != null;
Whether the current zone is collecting output instead of printing it.
static bool get isCapturing => Zone.current[_zoneSink] != null;