logCommand method
Logs the command that is about to run, as a shell-style $ line.
Implementation
void logCommand(String command) => _emit(
'\$ $command',
level: LogLevel.info,
style: _Ansi.gray,
);
Logs the command that is about to run, as a shell-style $ line.
void logCommand(String command) => _emit(
'\$ $command',
level: LogLevel.info,
style: _Ansi.gray,
);