logFilePath property

String logFilePath
getter/setter pair

The path of the file every log line is appended to.

Defaults to distribution.log in the current working directory and can be overridden through the global --log-file option. Set it to an empty string to disable file logging entirely.

Implementation

static String logFilePath = "distribution.log";