useUnicode property
Whether the unicode glyph set is used instead of the ASCII fallback.
Implementation
static bool useUnicode =
!Platform.environment.containsKey('DISTRIBUTE_ASCII');
Whether the unicode glyph set is used instead of the ASCII fallback.
static bool useUnicode =
!Platform.environment.containsKey('DISTRIBUTE_ASCII');