isError property
bool
get
isError
Whether messages of this level belong on stderr instead of stdout.
Implementation
bool get isError => this == LogLevel.error || this == LogLevel.errorVerbose;
Whether messages of this level belong on stderr instead of stdout.
bool get isError => this == LogLevel.error || this == LogLevel.errorVerbose;