describe property
Recomputes the label on every frame, when the caller has something that changes — the set of tasks currently running, for instance.
Implementation
final String Function()? describe;
Recomputes the label on every frame, when the caller has something that changes — the set of tasks currently running, for instance.
final String Function()? describe;