erase method
void
erase()
Removes the spinner's line, leaving the cursor at the start of the row.
Implementation
void erase() {
if (_painted == 0) return;
sink().write('\r${' ' * _painted}\r');
_painted = 0;
}
Removes the spinner's line, leaving the cursor at the start of the row.
void erase() {
if (_painted == 0) return;
sink().write('\r${' ' * _painted}\r');
_painted = 0;
}