CleanConfig class
Automatic cleanup performed after all jobs and run post-hooks finish.
Constructors
- CleanConfig({CleanOn on = CleanOn.success, bool flutter = true, bool outputs = true})
-
const
- CleanConfig.parse(dynamic raw)
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRun(
bool succeeded) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited