HookSet class

Hooks attached to one run, task, or job scope.

Constructors

HookSet({List<HookStep> pre = const [], List<HookStep> post = const []})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
post List<HookStep>
final
pre List<HookStep>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(Map<String, dynamic> map, String label) HookSet