HookStep class

One custom command executed before or after a run scope.

Constructors

HookStep({required String command, List<String> arguments = const [], String? workingDirectory, Map<String, String> environment = const {}, Duration? timeout, HookOn on = HookOn.always, bool continueOnError = false})
const
HookStep.parse(dynamic raw, String label)
factory

Properties

arguments List<String>
final
command String
final
continueOnError bool
final
environment Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
on HookOn
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration?
final
workingDirectory String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited