ErrorPolicy enum
Global reaction to a fatal task failure.
Values
- continueRun → const ErrorPolicy
-
Other independent tasks may still run.
- stop → const ErrorPolicy
-
Do not start new tasks after the first fatal failure.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
dynamic raw, {String label = 'on-error'}) → ErrorPolicy
Constants
-
values
→ const List<
ErrorPolicy> - A constant List of the values in this enum, in order of their declaration.