ParallelSettings class

Controls how tasks are admitted to the worker pool.

Constructors

ParallelSettings({int tasks = 1, Duration gap = Duration.zero})
const

Properties

gap Duration
Minimum time between two task starts across the whole run.
final
hashCode int
The hash code for this object.
no setterinherited
isAuto bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tasks int
Maximum number of tasks in flight. A very large value means auto.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(dynamic raw, String path) ParallelSettings

Constants

autoTaskCount → const int