RunStateStore class

Atomic reader/writer for .distribute/last-run.json.

Properties

file File
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state RunState
getter/setter pair

Methods

flush() Future<void>
job(String ref) Map<String, dynamic>?
mark(String ref, Map<String, dynamic> value) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setVersion(ResolvedVersion version) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required File file, required String configHash, required String operation}) Future<RunStateStore>
fingerprint(File config, String operation) String
load(File file) Future<RunStateStore>