Publisher class

Handles app publishing for Android and iOS.

Inheritance

Constructors

Publisher()
Default constructor.
Publisher.fromArgResults(ArgResults? argResults)
Creates a Publisher instance from command-line arguments.
factory

Properties

aliases List<String>
Alternate names for this command.
no setterinherited
argParser → ArgParser
Configures command-line arguments.
no setteroverride
argResults → ArgResults?
The parsed argument results for this command.
no setterinherited
category String
The command's category.
no setterinherited
description String
Command description.
no setteroverride
environment Environment
Environment configuration.
getter/setter pair
fastlanePromoteTrackTo String
Fastlane track for promotion.
getter/setter pair
fastlaneTrack String
Fastlane track for distribution.
getter/setter pair
globalResults → ArgResults?
The parsed global argument results.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
Whether or not this command should be hidden from help listings.
no setterinherited
invocation String
A single-line template for how to invoke this command (e.g. "pub get package").
no setterinherited
isAndroidDistribute bool
Enables Android distribution.
getter/setter pair
isIOSDistribute bool
Enables iOS distribution.
getter/setter pair
logger ColorizeLogger
Logger for logging messages.
latefinal
name String
Command name.
no setteroverride
parent → Command?
The command's parent command, if this is a subcommand.
no setterinherited
runner → CommandRunner?
The command runner for this command.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subcommands Map<String, Command>
An unmodifiable view of all sublevel commands of this command.
no setterinherited
suggestionAliases List<String>
Alternate non-functional names for this command.
no setterinherited
summary String
A short description of this command, included in parent's CommandRunner.usage.
no setterinherited
takesArguments bool
Whether or not this command takes positional arguments in addition to options.
no setterinherited
usage String
Generates a string displaying usage information for this command.
no setterinherited
usageFooter String?
An optional footer for usage.
no setterinherited
useFastlane bool
Uses Fastlane for distribution.
getter/setter pair
useFirebase bool
Uses Firebase for distribution.
getter/setter pair

Methods

addSubcommand(Command command) → void
Adds Command as a subcommand of this.
inherited
buildAndroidDocs() Future<int>
Builds Android changelogs.
distributeAndroid() Future<int>
Distributes Android binaries.
distributeIOS() Future<int>
Distributes iOS binaries.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printUsage() → void
Prints the usage information for this command.
inherited
run() Future?
Executes the publishing process.
override
toString() String
A string representation of this object.
inherited
usageException(String message) → Never
Throws a UsageException with message.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited