PublisherCommand class
A command to publish the app to various distribution platforms.
The PublisherCommand class provides subcommands for publishing the app
to different platforms including Firebase App Distribution, Google Play
Store, App Store, GitHub releases, and Huawei AppGallery. Each subcommand
handles the publishing process for its respective platform.
Constructors
- PublisherCommand()
- Creates a new PublisherCommand and registers platform-specific publish subcommands.
Properties
-
aliases
→ List<
String> -
Alternate names for this command.
no setterinherited
- argParser → ArgParser
-
The argument parser for this command.
no setterinherited
- argResults → ArgResults?
-
The parsed argument results for this command.
no setterinherited
- category → String
-
The command's category.
no setterinherited
- configPath → String
-
The configuration file this command should read.
no setterinherited
- description → String
-
The description of the publish command shown in help text.
no setteroverride
- globalResults → ArgResults?
-
The parsed global argument results.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether or not this command should be hidden from help listings.
no setterinherited
- invocation → String
-
A single-line template for how to invoke this command (e.g.
"pub getpackage").no setterinherited - logger → ColorizeLogger
-
The logger used by this command.
no setterinherited
- name → String
-
The name of the command used in CLI.
no setteroverride
-
parent
→ Command<
int> ? -
The command's parent command, if this is a subcommand.
no setterinherited
-
runner
→ CommandRunner<
int> ? -
The command runner for this command.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subcommands
→ Map<
String, Command< int> > -
An unmodifiable view of all sublevel commands of this command.
no setterinherited
-
suggestionAliases
→ List<
String> -
Alternate non-functional names for this command.
no setterinherited
- summary → String
-
A short description of this command, included in
parent'sCommandRunner.usage.no setterinherited - takesArguments → bool
-
Whether or not this command takes positional arguments in addition to
options.
no setterinherited
- usage → String
-
Generates a string displaying usage information for this command.
no setterinherited
-
An optional footer for
usage.no setterinherited
Methods
-
addSubcommand(
Command< int> command) → void -
Adds
Commandas a subcommand of this.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printUsage(
) → void -
Prints the usage information for this command.
inherited
-
run(
) → FutureOr< int> ? -
Runs this command.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
usageException(
String message) → Never -
Throws a
UsageExceptionwithmessage.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited