runner_command library

Classes

JobResult
The outcome of a single executed job, used to build the final summary.
RunnerCommand
A command to execute distribution tasks defined in the configuration file.