isFatal property
bool
get
isFatal
Whether the job failed in a way that must fail the whole run.
Implementation
bool get isFatal => !succeeded && !ignored;
Whether the job failed in a way that must fail the whole run.
bool get isFatal => !succeeded && !ignored;