description property

  1. @override
String get description
override

The description of the run command shown in help text

Implementation

@override
String get description =>
    "Run the tasks and jobs declared in the configuration.";