failFast property
bool
get
failFast
Whether the run stops at the first failing task.
Implementation
bool get failFast =>
argResults!['fail-fast'] as bool || _errorPolicy == ErrorPolicy.stop;
Whether the run stops at the first failing task.
bool get failFast =>
argResults!['fail-fast'] as bool || _errorPolicy == ErrorPolicy.stop;