isDryRun property
bool
get
isDryRun
Whether the run should only print the resolved commands.
Implementation
bool get isDryRun => argResults!['dry-run'] as bool;
Whether the run should only print the resolved commands.
bool get isDryRun => argResults!['dry-run'] as bool;