packageVersion top-level constant

String const packageVersion

The current version of the Distribute CLI.

Keep this value in sync with the version field in pubspec.yaml. It is surfaced through the global --version flag and written to the header of distribution.log to make bug reports easier to triage.

Implementation

const String packageVersion = '2.8.0';