toolDescription constant
String
const toolDescription
Description of the tool exposed to the model.
Implementation
static const String toolDescription =
'Run a distribute_cli command on the user\'s Flutter project. Call this '
'whenever the user asks to build, publish, release, check, or validate '
'anything. Prefer the most specific operation key that matches the '
'request.';