obfuscate property
Enables Dart code obfuscation for release builds.
When true, identifiers are replaced with randomized values to make
reverse engineering harder. Flutter requires this flag to be combined with
splitDebugInfo; a default directory is substituted when none is given.
Implementation
final bool? obfuscate;