changesNotSentForReview property
Whether changes require manual review approval.
When true, indicates that changes in this edit will not be
automatically reviewed and must be explicitly sent for review
from the Google Play Console UI. Used for policy-sensitive
changes or complex releases.
Default: false
Implementation
final bool changesNotSentForReview;