versionCode property
Application version code for the release.
Integer version identifier used for version ordering and updates. Must be higher than the previous release for updates to work properly. Example: 42
Implementation
final int? versionCode;