run method
Executes the command.
Parses the arguments and publishes the Android application using the Arguments class. Returns a Future that completes with the exit code of the publish process.
Implementation
@override
Future? run() async =>
Arguments.fromArgResults(argResults!, globalResults).publish();