parent property
Reference to the parent publisher job that contains this publisher.
Used for accessing job-level configuration and establishing the configuration hierarchy between jobs and publishers.
Implementation
late PublisherJob parent;
Reference to the parent publisher job that contains this publisher.
Used for accessing job-level configuration and establishing the configuration hierarchy between jobs and publishers.
late PublisherJob parent;