bundleVersion property
Bundle version (CFBundleVersion) of the application.
The build number or version identifier for the specific build. Must be unique for each submission to App Store Connect. Typically incremented for each build.
Example: "42" or "2024.1.15.1"
Implementation
final String? bundleVersion;