CreatorCommand class abstract
Abstract base class for commands that create jobs or tasks.
- Inheritance
- Implementers
Constructors
Properties
-
aliases
→ List<
String> -
Alternate names for this command.
no setterinherited
- argParser → ArgParser
-
The argument parser for this command.
no setterinherited
- argResults → ArgResults?
-
The parsed argument results for this command.
no setterinherited
- category → String
-
The command's category.
no setterinherited
- configPath → String
-
The configuration file this command should read.
no setterinherited
- description → String
-
A description of this command, included in
usage.no setterinherited - globalResults → ArgResults?
-
The parsed global argument results.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether or not this command should be hidden from help listings.
no setterinherited
- invocation → String
-
A single-line template for how to invoke this command (e.g.
"pub getpackage").no setterinherited - logger → ColorizeLogger
-
The logger used by this command.
no setterinherited
- name → String
-
The name of this command.
no setterinherited
-
parent
→ Command<
int> ? -
The command's parent command, if this is a subcommand.
no setterinherited
-
runner
→ CommandRunner<
int> ? -
The command runner for this command.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subcommands
→ Map<
String, Command< int> > -
An unmodifiable view of all sublevel commands of this command.
no setterinherited
-
suggestionAliases
→ List<
String> -
Alternate non-functional names for this command.
no setterinherited
- summary → String
-
A short description of this command, included in
parent'sCommandRunner.usage.no setterinherited - takesArguments → bool
-
Whether or not this command takes positional arguments in addition to
options.
no setterinherited
- usage → String
-
Generates a string displaying usage information for this command.
no setterinherited
-
An optional footer for
usage.no setterinherited
Methods
-
addSubcommand(
Command< int> command) → void -
Adds
Commandas a subcommand of this.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openWizard(
String title, String configPath) → Prompt - Prints the wizard header and returns the prompt to drive it with.
-
printUsage(
) → void -
Prints the usage information for this command.
inherited
-
run(
) → Future< int> -
Runs the command to create a job and update the config file.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
usageException(
String message) → Never -
Throws a
UsageExceptionwithmessage.inherited -
warnIfComments(
File file) → bool - Says that comments are about to be lost. Returns whether it warned.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
slugify(
String name) → String - Turns a human readable name into a usable key.
-
validateKey(
String value, {required Set< String> taken, required String what}) → String? - Rejects a key that is unusable or already taken, for Prompt.text.