HooksRunner class
Executes custom hook commands with the same variable and logging rules as jobs.
Constructors
- HooksRunner(ColorizeLogger logger, Variables variables, {required bool dryRun})
-
const
Properties
- dryRun → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → ColorizeLogger
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variables → Variables
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
List< HookStep> steps, {required String phase, required bool scopeSucceeded, Map<String, String> context = const {}, Map<String, String> variableContext = const {}}) → Future<List< HookResult> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited