LogLevel enum

Represents the log levels with associated ANSI color codes.

The LogLevel enum defines different log levels, such as info, warning, success, debug, and error. Each log level is associated with a specific ANSI color code for better visibility in the terminal.

Inheritance
Available extensions

Values

info → const LogLevel

Informational log level with orange color.

const LogLevel('\x1B[33m')
warning → const LogLevel

Warning log level with yellow color.

const LogLevel('\x1B[33m')
success → const LogLevel

Success log level with green color.

const LogLevel('\x1B[32m')
debug → const LogLevel

Debug log level with default terminal color.

const LogLevel('\x1B[0m')
error → const LogLevel

Error log level with red color.

const LogLevel('\x1B[31m')

Properties

color String
The ANSI color code for the log level.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LogLevel>
A constant List of the values in this enum, in order of their declaration.