CleanConfig class

Automatic cleanup performed after all jobs and run post-hooks finish.

Constructors

CleanConfig({CleanOn on = CleanOn.success, bool flutter = true, bool outputs = true})
const
CleanConfig.parse(dynamic raw)
factory

Properties

flutter bool
final
hashCode int
The hash code for this object.
no setterinherited
on CleanOn
final
outputs bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRun(bool succeeded) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited