RunState class
Persistent state used to continue an interrupted run safely.
Constructors
Properties
- configHash → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
jobs
→ Map<
String, Map< String, dynamic> > -
final
- operation → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt → DateTime
-
final
- updatedAt ↔ DateTime
-
getter/setter pair
- version ↔ ResolvedVersion?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- currentSchema → const int