VersionConfig class

Optional run-level version resolution settings.

Constructors

VersionConfig({String? name, required String code, required VersionCodeSource codeSource, bool writeBack = false})
const
VersionConfig.parse(dynamic raw)
factory

Properties

code String
final
codeSource VersionCodeSource
final
hashCode int
The hash code for this object.
no setterinherited
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writeBack bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited