menu
distribute_cli package
documentation
runner_command.dart
runner_command.dart
dark_mode
light_mode
runner_command
library
Classes
JobResult
The outcome of a single executed job, used to build the final summary.
RunnerCommand
A command to execute distribution tasks defined in the configuration file.
distribute_cli package
documentation
runner_command.dart
distribute_cli
package
Libraries
ai/ai_config
ai/ai_provider
ai/ai_reference
ai/providers
ai_command
app_builder/android/arguments
app_builder/android/command
app_builder/build_arguments
app_builder/custom/arguments
app_builder/custom/command
app_builder/ios/arguments
app_builder/ios/command
app_publisher/fastlane/arguments
app_publisher/fastlane/command
app_publisher/firebase/arguments
app_publisher/firebase/command
app_publisher/github/arguments
app_publisher/github/command
app_publisher/publisher_arguments
app_publisher/xcrun/arguments
app_publisher/xcrun/command
builder_command
changelog_command
command
create_command
doctor_command
files
initializer_command
logger
parsers/artifact_report
parsers/build_info
parsers/builtin_variables
parsers/changelog
parsers/compress_files
parsers/config_parser
parsers/job_arguments
parsers/notification_config
parsers/task_arguments
parsers/variables
prompt
publisher_command
runner_command
validate_command
version
runner_command library