RunnerCommand class
A command to execute distribution tasks defined in the configuration file.
The RunnerCommand class is responsible for parsing the configuration file,
filtering tasks and jobs based on the provided operation key, and executing
the specified build and publish operations. It supports running individual
jobs or entire task workflows.
The command returns the process exit code: 0 when every job succeeded (or
failed with continue-on-error), 1 otherwise.
Constructors
Properties
-
aliases
→ List<
String> -
Alternate names for this command.
no setterinherited
- argParser → ArgParser
-
Argument parser for the run command with configuration and operation options.
no setteroverride
- argResults → ArgResults?
-
The parsed argument results for this command.
no setterinherited
- category → String
-
The command's category.
no setterinherited
- configPath → String
-
The configuration file this command should read.
no setterinherited
- description → String
-
The description of the run command shown in help text
no setteroverride
- failFast → bool
-
Whether the run stops at the first failing task.
no setter
- globalResults → ArgResults?
-
The parsed global argument results.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether or not this command should be hidden from help listings.
no setterinherited
- invocation → String
-
A single-line template for how to invoke this command (e.g.
"pub getpackage").no setterinherited - isDryRun → bool
-
Whether the run should only print the resolved commands.
no setter
- logger → ColorizeLogger
-
The logger used by this command.
no setterinherited
- name → String
-
The name of the command used in CLI
no setteroverride
- operationKey → String
-
The operation key used to filter which tasks or jobs to execute.
no setter
-
parent
→ Command<
int> ? -
The command's parent command, if this is a subcommand.
no setterinherited
-
runner
→ CommandRunner<
int> ? -
The command runner for this command.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subcommands
→ Map<
String, Command< int> > -
An unmodifiable view of all sublevel commands of this command.
no setterinherited
-
suggestionAliases
→ List<
String> -
Alternate non-functional names for this command.
no setterinherited
- summary → String
-
A short description of this command, included in
parent'sCommandRunner.usage.no setterinherited - takesArguments → bool
-
Whether or not this command takes positional arguments in addition to
options.
no setterinherited
- usage → String
-
Generates a string displaying usage information for this command.
no setterinherited
-
An optional footer for
usage.no setterinherited
Methods
-
addSubcommand(
Command< int> command) → void -
Adds
Commandas a subcommand of this.inherited -
configParserBuilder(
) → Future< ConfigParser?> - Kept for backwards compatibility with external callers.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printUsage(
) → void -
Prints the usage information for this command.
inherited
-
run(
) → Future< int> -
Executes the run command to process distribution tasks.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
usageException(
String message) → Never -
Throws a
UsageExceptionwithmessage.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited