argParser property
Argument parser for the run command with configuration and operation options.
Available options:
--configor-c- Path to the configuration file (defaults to "distribution.yaml")--operationor-o- Key of the operation to run (use "TaskKey.JobKey" for specific jobs)--dry-run- Resolve and print every command without executing it--fail-fast- Stop as soon as a task fails--list- Print the available tasks and jobs, then exit
Implementation
@override
ArgParser get argParser => ArgParser()
..addOption(
'config',
abbr: 'c',
help: 'Path to the configuration file.',
defaultsTo: 'distribution.yaml',
)
..addOption(
'operation',
abbr: 'o',
help: 'Run a single task ("android") or a single job ("android.build").',
defaultsTo: '',
)
..addFlag(
'dry-run',
negatable: false,
defaultsTo: false,
help: 'Resolve and print every command without executing it.',
)
..addFlag(
'fail-fast',
negatable: false,
defaultsTo: false,
help: 'Stop the run as soon as a task fails.',
)
..addFlag(
'list',
abbr: 'l',
negatable: false,
defaultsTo: false,
help: 'List the available tasks and jobs, then exit.',
)
..addFlag(
'json',
negatable: false,
defaultsTo: false,
help: 'Print a machine readable run report to stdout. '
'The human readable log moves to stderr.',
)
..addOption(
'json-file',
help: 'Write the machine readable run report to the given path.',
)
..addFlag(
'no-notify',
negatable: false,
defaultsTo: false,
help: 'Skip the notifications declared in the configuration.',
);